.. _toolkits-index:

########
Toolkits
########

.. htmlonly::

   :Release: |version|
   :Date: |today|

.. _toolkits:

Toolkits are collections of application-specific functions that extend matplotlib.

.. _toolkit_basemap:

Basemap
=======

Plots data on map projections, with continental and political
boundaries, see `basemap <http://matplotlib.sf.net/basemap/doc/html>`_
docs.

.. _toolkit_gtk:

GTK Tools
=========

mpl_toolkits.gtktools provides some utilities for working with GTK.
This toolkit ships with matplotlib, but requires `pygtk
<http://www.pygtk.org/>`_.

.. _toolkit_excel:

Excel Tools
===========

mpl_toolkits.exceltools provides some utilities for working with
Excel.  This toolkit ships with matplotlib, but requires
`xlwt <http://pypi.python.org/pypi/xlwt>`_

.. _toolkit_natgrid:

Natgrid
========

mpl_toolkits.natgrid is an interface to natgrid C library for gridding
irregularly spaced data.  This requires a separate installation of the
natgrid toolkit from the sourceforge `download
<http://sourceforge.net/project/showfiles.php?group_id=80706&package_id=142792>`_
page.

.. _toolkit_mplot3d:

mplot3d
===========

mpl_toolkits.mplot3d provides some basic 3D plotting (scatter, surf,
line, mesh) tools.  Not the fastest or feature complete 3D library out
there, but ships with matplotlib and thus may be a lighter weight
solution for some use cases.

See :ref:`toolkit_mplot3d-index` for more documentation and examples.

.. _toolkit_axes_grid:

AxesGrid
========

The matplotlib AxesGrid toolkit is a collection of helper classes to
ease displaying multiple images in matplotlib. The AxesGrid toolkit is
distributed with matplotlib source.

.. image:: ../_static/demo_axes_grid.png

See :ref:`toolkit_axesgrid-index` for documentations.
